@@ -115,7 +115,7 @@ private Q_SLOTS:
     void slotGrantleeThemesUpdated();
     void slotCheckNewCalendar(const QModelIndex &parent, int begin, int end);
 
-    void slotDebugBaloo();
+    void slotDebugAkonadiSearch();
     void slotServerSideSubscription();
     void slotCurrentCollectionChanged(const Akonadi::Collection &col);
     void setFocusToTreeView();
@@ -129,45 +129,45 @@ private:
     void saveSplitterStates() const;
     void restoreSplitterStates();
     void initializeImportExportPlugin(KActionCollection *collection);
+    Akonadi::EntityTreeModel *entityTreeModel() const;
 
     QAbstractItemModel *allContactsModel();
 
-    Akonadi::EntityMimeTypeFilterModel *mCollectionTree;
-    Akonadi::EntityMimeTypeFilterModel *mItemTree;
-    Akonadi::EntityMimeTypeFilterModel *mAllContactsModel;
-    Akonadi::ContactsFilterProxyModel *mContactsFilterModel;
-    CategoryFilterProxyModel *mCategoryFilterModel;
+    Akonadi::EntityMimeTypeFilterModel *mCollectionTree = nullptr;
+    Akonadi::EntityMimeTypeFilterModel *mItemTree = nullptr;
+    Akonadi::EntityMimeTypeFilterModel *mAllContactsModel = nullptr;
+    Akonadi::ContactsFilterProxyModel *mContactsFilterModel = nullptr;
+    CategoryFilterProxyModel *mCategoryFilterModel = nullptr;
 
-    QuickSearchWidget *mQuickSearchWidget;
-    Akonadi::EntityTreeView *mCollectionView;
-    Akonadi::EntityTreeView *mItemView;
-    CategorySelectWidget *mCategorySelectWidget;
+    QuickSearchWidget *mQuickSearchWidget = nullptr;
+    Akonadi::EntityTreeView *mCollectionView = nullptr;
+    Akonadi::EntityTreeView *mItemView = nullptr;
+    CategorySelectWidget *mCategorySelectWidget = nullptr;
 
-    QWidget *mDetailsPane;
-    QStackedWidget *mDetailsViewStack;
-    ContactSwitcher *mContactSwitcher;
+    QWidget *mDetailsPane = nullptr;
+    QStackedWidget *mDetailsViewStack = nullptr;
+    ContactSwitcher *mContactSwitcher = nullptr;
 
-    QSplitter *mMainWidgetSplitter1;
-    QSplitter *mMainWidgetSplitter2;
-    Akonadi::ContactViewer *mContactDetails;
-    Akonadi::ContactGroupViewer *mContactGroupDetails;
-    QWidget *mEmptyDetails;
-    Akonadi::StandardContactActionManager *mActionManager;
-    QItemSelectionModel *mCollectionSelectionModel;
+    QSplitter *mMainWidgetSplitter1 = nullptr;
+    QSplitter *mMainWidgetSplitter2 = nullptr;
+    Akonadi::ContactViewer *mContactDetails = nullptr;
+    Akonadi::ContactGroupViewer *mContactGroupDetails = nullptr;
+    QWidget *mEmptyDetails = nullptr;
+    Akonadi::StandardContactActionManager *mActionManager = nullptr;
+    QItemSelectionModel *mCollectionSelectionModel = nullptr;
 
-    QActionGroup *mViewModeGroup;
+    QActionGroup *mViewModeGroup = nullptr;
 
-    ModelColumnManager *mModelColumnManager;
-    KXMLGUIClient *mXmlGuiClient;
-    KAddressBookGrantlee::GrantleeContactFormatter *mFormatter;
-    KAddressBookGrantlee::GrantleeContactGroupFormatter *mGroupFormatter;
-    GrantleeTheme::ThemeManager *mGrantleeThemeManager;
-    Akonadi::EntityTreeModel *entityTreeModel() const;
-    QAction *mQuickSearchAction;
-    QAction *mServerSideSubscription;
-    KAddressBookImportExport::KAddressBookImportExportPluginManager *mImportExportPluginManager;
+    ModelColumnManager *mModelColumnManager = nullptr;
+    KXMLGUIClient *mXmlGuiClient = nullptr;
+    KAddressBookGrantlee::GrantleeContactFormatter *mFormatter = nullptr;
+    KAddressBookGrantlee::GrantleeContactGroupFormatter *mGroupFormatter = nullptr;
+    GrantleeTheme::ThemeManager *mGrantleeThemeManager = nullptr;
+    QAction *mQuickSearchAction = nullptr;
+    QAction *mServerSideSubscription = nullptr;
+    KAddressBookImportExport::KAddressBookImportExportPluginManager *mImportExportPluginManager = nullptr;
     QList<KAddressBookImportExport::KAddressBookImportExportPluginInterface *> mImportExportPluginInterfaceList;
-    ManageShowCollectionProperties *mManageShowCollectionProperties;
+    ManageShowCollectionProperties *mManageShowCollectionProperties = nullptr;
 };
 
 #endif
